@@ -1,6 +1,6 @@
 //! Arima order, can be used for both non-seasonal and seasonal parts.
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct ArimaOrder {
     /// Order of the moving-average part.
