@@ -2,7 +2,7 @@ use serde::{Deserialize, Serialize};
 
 /// BqmlTrainingRunTrainingOptions : [Output-only, Beta] Training options used by this training run. These options are mutable for subsequent training runs. Default values are explicitly stored for options not specified in the input query of the first training run. For subsequent training runs, any option not explicitly specified in the input query will be copied from the previous training run.
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct BqmlTrainingRunTrainingOptions {
     #[serde(skip_serializing_if = "Option::is_none")]
