@@ -1,7 +1,7 @@
 //! Evaluation metrics for clustering models.
 use crate::model::cluster::Cluster;
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct ClusteringMetrics {
     /// Davies-Bouldin index.
