@@ -1,6 +1,6 @@
 use crate::model::job::Job;
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct JobCancelResponse {
     #[serde(skip_serializing_if = "Option::is_none")]
