@@ -4,7 +4,9 @@ use serde::{Deserialize, Serialize};
 #[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct QueryParameterType {
-    pub array_type: Box<QueryParameterType>,
+    /// [Optional] The type of the array's elements, if this is an array.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub array_type: Option<Box<QueryParameterType>>,
     /// [Optional] The types of the fields of this struct, in order, if this is a struct.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub struct_types: Option<Vec<QueryParameterTypeStructTypes>>,
