@@ -1,7 +1,7 @@
 //! A single row in the confusion matrix.
 use crate::model::entry::Entry;
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Row {
     /// The original label of this row.
