@@ -1,7 +1,7 @@
 use crate::model::script_stack_frame::ScriptStackFrame;
 use serde::{Deserialize, Serialize};
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct ScriptStatistics {
     /// [Output-only] Whether this child job was a statement or expression.
