@@ -1,7 +1,7 @@
 use crate::model::table_data_insert_all_response_insert_errors::TableDataInsertAllResponseInsertErrors;
 use serde::{Deserialize, Serialize};
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct TableDataInsertAllResponse {
     /// An array of errors for rows that were not inserted.
