@@ -1,7 +1,7 @@
 use crate::model::table_list_tables::TableListTables;
 use serde::{Deserialize, Serialize};
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct TableList {
     /// A hash of this page of results.
