@@ -1,7 +1,7 @@
 use crate::model::table_cell::TableCell;
 use serde::{Deserialize, Serialize};
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct TableRow {
     /// Represents a single row in the result set, consisting of one or more fields.
