@@ -2,7 +2,7 @@ use serde::{Deserialize, Serialize};
 
 /// TestIamPermissionsRequest : Request message for `TestIamPermissions` method.
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct TestIamPermissionsRequest {
     /// The set of permissions to check for the `resource`. Permissions with wildcards (such as '*' or 'storage.*')
