@@ -2,7 +2,7 @@ use serde::{Deserialize, Serialize};
 
 /// TestIamPermissionsResponse : Response message for `TestIamPermissions` method.
 
-#[derive(Debug, Serialize, Deserialize)]
+#[derive(Debug, Default, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct TestIamPermissionsResponse {
     /// A subset of `TestPermissionsRequest.permissions` that the caller is allowed.
