@@ -4,16 +4,16 @@ use crate::model::evaluation_metrics::EvaluationMetrics;
 use crate::model::global_explanation::GlobalExplanation;
 use crate::model::iteration_result::IterationResult;
 use crate::model::training_options::TrainingOptions;
-use chrono::DateTime;
-use chrono::Utc;
+use time::OffsetDateTime;
 
-#[derive(Debug, Default, Clone, Serialize, Deserialize)]
+#[derive(Debug, Clone, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct TrainingRun {
     /// The evaluation metrics over training/eval data that were computed at the end of training.
     pub evaluation_metrics: Option<EvaluationMetrics>,
     /// The start time of this training run.
-    pub start_time: Option<DateTime<Utc>>,
+    #[serde(with = "time::serde::rfc3339")]
+    pub start_time: OffsetDateTime,
     /// Data split result of the training run. Only set when the input data is actually split.
     pub data_split_result: Option<DataSplitResult>,
     /// Options that were used for this training run, includes user specified and default options that were used.
@@ -23,3 +23,16 @@ pub struct TrainingRun {
     /// Output of each iteration run, results.size() <= max_iterations.
     pub results: Option<Vec<IterationResult>>,
 }
+
+impl Default for TrainingRun {
+    fn default() -> Self {
+        Self {
+            evaluation_metrics: None,
+            start_time: OffsetDateTime::now_utc(),
+            data_split_result: None,
+            training_options: None,
+            global_explanations: None,
+            results: None,
+        }
+    }
+}
